@@ -6,7 +6,9 @@ import uuid
 from copy import copy
 from socket import gethostname
 import logging
+from io import BytesIO
 
+import numpy as np
 import cloudpickle as pickle
 import gcsfs
 
@@ -26,10 +28,10 @@ class Timer(object):
         return self._time
 
 
-def open_file(path, mode='rb'):
+def open_file(path, mode='rb', cache_type='readahead'):
     if path.startswith("gs://"):
         logging.getLogger("fsspec").setLevel(logging.WARNING)
-        return gcsfs.GCSFileSystem().open(path, mode, cache_type='block')
+        return gcsfs.GCSFileSystem().open(path, mode, cache_type=cache_type)
     else:
         return open(path, mode)
 
@@ -43,3 +45,13 @@ def load_pickle(path):
     with open_file(path, 'rb') as fin:
         data = pickle.load(fin)
     return data
+
+
+def text_to_array(text, encoding='utf-8'):
+    return np.frombuffer(text.encode(encoding), dtype='uint8')
+
+
+def array_to_text(array, encoding='utf-8'):
+    with BytesIO(array) as fin:
+        text = fin.read().decode(encoding)
+    return text
